@@ -151,6 +151,15 @@ class Chunk(object):
                         stderr=subprocess.PIPE)
                     file_obj = xz_child.stdout
                     ## what to do with stderr
+                elif path.endswith('.xz.gpg'):
+                    assert mode == 'rb', 'mode=%r for .xz' % mode
+                    ## launch xz child
+                    xz_child = subprocess.Popen(
+                        ['gpg -d %s | xz --decompress' % path],
+                        stdout=subprocess.PIPE, shell=True)
+                        #stderr=subprocess.PIPE)
+                    file_obj = xz_child.stdout
+                    ## what to do with stderr?
                 else:
                     file_obj = open(path, mode)
             else:
@@ -199,8 +208,7 @@ class Chunk(object):
         else:
             assert mode == 'rb', mode
             self._i_chunk_fh = md5_file( file_obj )
-            self._i_transport = TTransport.TBufferedTransport(self._o_chunk_fh)
-            self._i_protocol = TBinaryProtocol.TBinaryProtocol(self._o_transport)
+            #_i_transport and _i_protocol are set below in __iter__
 
     def __enter__(self):
         return self
@@ -256,13 +264,15 @@ class Chunk(object):
         '''
         assert self._i_chunk_fh, 'cannot iterate over a Chunk open for writing'
 
-        ## seek to the start, so can iterate multiple times over the chunk
-        try:
-            self._i_chunk_fh.seek(0)
-        except IOError:
-            pass
-            ## just assume that it is a pipe like stdin that need not
-            ## be seeked to start
+        ## attempt to seek to the start, so can iterate multiple times
+        ## over the chunk
+        if hasattr(self._i_chunk_fh, 'seek'):
+            try:
+                self._i_chunk_fh.seek(0)
+            except IOError:
+                pass
+                ## just assume that it is a pipe like stdin that need
+                ## not be seeked to start
 
         ## wrap the file handle in buffered transport
         i_transport = TTransport.TBufferedTransport(self._i_chunk_fh)
